@@ -5,7 +5,7 @@ import importlib.metadata
 from rich import print
 from typer import Typer
 
-from .commands import auth_command, local_command
+from .commands import local_command
 
 app = Typer()
 
@@ -13,4 +13,3 @@ app.command(name="version", help="Show the Lilypad version.")(
     lambda: print(importlib.metadata.version("python-lilypad"))
 )
 app.command(name="local", help="Run Lilypad Locally")(local_command)
-app.command(name="auth", help="Authenticate with Lilypad")(auth_command)
