@@ -1,16 +1,13 @@
-"""API key table and models."""
+"""API key models."""
 
 from datetime import datetime, timedelta, timezone
 from typing import TYPE_CHECKING
 from uuid import UUID
 
-from pydantic import computed_field
 from sqlmodel import Field, Relationship, SQLModel
 
 from .base_organization_sql_model import BaseOrganizationSQLModel
-from .projects import ProjectPublic
 from .table_names import API_KEY_TABLE_NAME, PROJECT_TABLE_NAME, USER_TABLE_NAME
-from .users import UserPublic
 
 if TYPE_CHECKING:
     from .projects import ProjectTable
@@ -18,7 +15,7 @@ if TYPE_CHECKING:
     from .users import UserTable
 
 
-class _APIKeyBase(SQLModel):
+class APIKeyBase(SQLModel):
     """Base APIKey Model."""
 
     name: str = Field(nullable=False, min_length=1)
@@ -31,7 +28,7 @@ class _APIKeyBase(SQLModel):
     )
 
 
-class APIKeyTable(_APIKeyBase, BaseOrganizationSQLModel, table=True):
+class APIKeyTable(APIKeyBase, BaseOrganizationSQLModel, table=True):
     """APIKey table."""
 
     __tablename__ = API_KEY_TABLE_NAME  # type: ignore
@@ -42,24 +39,3 @@ class APIKeyTable(_APIKeyBase, BaseOrganizationSQLModel, table=True):
     organization: "OrganizationTable" = Relationship(back_populates="api_keys")
     project: "ProjectTable" = Relationship(back_populates="api_keys")
     user: "UserTable" = Relationship(back_populates="api_keys")
-
-
-class APIKeyPublic(_APIKeyBase):
-    """API key public model"""
-
-    uuid: UUID
-    key_hash: str = Field(exclude=True)
-    user: UserPublic
-    project: ProjectPublic
-
-    @computed_field
-    @property
-    def prefix(self) -> str:
-        """Return the first 8 characters of the key_hash."""
-        return self.key_hash[:8]
-
-
-class APIKeyCreate(_APIKeyBase):
-    """API key create model"""
-
-    key_hash: str | None = None
