@@ -18,18 +18,25 @@ class BaseOrganizationService(BaseService[_TableT, _CreateT]):
 
     def find_record_by_uuid(self, uuid: UUID, **filters: Any) -> _TableT:
         """Find record by uuid with organization filter"""
+        organization_uuid = filters.pop(
+            "organization_uuid", self.user.active_organization_uuid
+        )
         return super().find_record_by_uuid(
-            uuid, organization_uuid=self.user.active_organization_uuid, **filters
+            uuid, organization_uuid=organization_uuid, **filters
         )
 
     def find_all_records(self, **filters: Any) -> Sequence[_TableT]:
         """Find all records with organization filter"""
-        return super().find_all_records(
-            organization_uuid=self.user.active_organization_uuid, **filters
+        organization_uuid = filters.pop(
+            "organization_uuid", self.user.active_organization_uuid
         )
+        return super().find_all_records(organization_uuid=organization_uuid, **filters)
 
     def create_record(self, data: _CreateT, **kwargs: Any) -> _TableT:
         """Create a new record with organization"""
+        organization_uuid = kwargs.pop(
+            "organization_uuid", self.user.active_organization_uuid
+        )
         return super().create_record(
-            data, organization_uuid=self.user.active_organization_uuid, **kwargs
+            data, organization_uuid=organization_uuid, **kwargs
         )
